@@ -117,7 +117,9 @@ internal_graphicModule <-
                 group.pch = "different"
         }
         
-        df$pch.levels = factor(as.character(df$pch.levels)) #forced to be character,
+        # removed code to force as.character below because pch.levels should never be reordered, always the same (1, 2, 3, 4..) and they should always match the order of df$group levels
+        df$pch.levels = factor(as.numeric(df$pch.levels))
+        #df$pch.levels = factor(as.character(df$pch.levels)) #forced to be character,
         #   so that the order of the levels is the same all the time
         #   (1, 10, 11, 12, 2, 3...), instead of changing between ggplot2 and
         #   the rest
@@ -218,25 +220,30 @@ internal_graphicModule <-
             
             
             #-- Modify scale colour - Change X/Ylabel - split plots into Blocks
-            p = p + scale_color_manual(values = unique(col.per.group)[match(
-                levels(factor(as.character(df$group))), levels(df$group))],
-                name = legend.title)
+            ## order of 'col.per.group' will correspond to order of levels in 'df$group'
+            p = p + scale_color_manual(values = col.per.group, name = legend.title)
             
             
             if(group.pch == "same")
             {
-                p = p + scale_shape_manual(values = values.pch[match(
-                    levels(factor(as.character(df$pch.levels))),levels(df$pch.levels))],
+                p = p + scale_shape_manual(values = values.pch,
                     name = legend.title, labels = levels(factor(df$group)),
                     guide = "none")
                 #match(..) reorder the values as the values of pch.levels,
                 #if there's more than 10 levels, R/ggplot orders characters
                 #different than values 1, 10, 11, 2, 3, etc
             } else {
-                # if pch different factor, then second legend
-                p = p + scale_shape_manual(values = values.pch[match(
-                    levels(factor(as.character(df$pch.levels))),levels(df$pch.levels))],
-                    name = legend.title.pch, labels = levels(df$pch.levels))
+                # if pch different factor, then can't plot samples per group as done before, restart plot
+                p = ggplot(df, aes(x = x, y = y, color = group, shape = pch)) +
+                  labs(title=title, x = X.label, y = Y.label) +
+                  theme_bw() + 
+                  theme(strip.text = element_text(size = size.subtitle, face = "bold")) + 
+                  geom_point(data = df,
+                             size = df$cex[1], 
+                             stroke = point.lwd) + 
+                  scale_shape_manual(values = values.pch,
+                    name = legend.title.pch, labels = values.pch) +
+                  scale_color_manual(values = col.per.group, name = legend.title)
             }
             
             p = p + #labs(list(title = title, x = X.label, y = Y.label)) +
@@ -294,12 +301,13 @@ internal_graphicModule <-
                 if (display.names | any(class.object%in%object.mint) ) {
                     group.shape <- 19
                 } else {
-                    group.shape <- unique(df$pch.legend)
+                    # keep order of pch.levels the same
+                    group.shape <- as.numeric(levels(df$pch.levels))
                     
                     if (length(group.shape) > 1)
                     {
-                        names(group.shape) <- unique(df$group)
-                        group.shape <- group.shape[sort(names(group.shape))]
+                        # keep order of df$group levels the same
+                        names(group.shape) <- levels(df$pch.legend)
                     }
                 }
                 
@@ -333,7 +341,7 @@ internal_graphicModule <-
                                                            levels(df$group)[i]),
                                          aes(x = x0, y = y0, xend = x, yend = y),
                                          #label = "Block"),
-                                         color = unique(col.per.group)[i],size = point.lwd)
+                                         color = unique(col.per.group)[i], linewidth = point.lwd)
                 }
             }
             
@@ -398,8 +406,7 @@ internal_graphicModule <-
             }
             
             #-- Modify scale colour - Change X/Ylabel - split plots into Blocks
-            p = p + scale_colour_manual(values = unique(col.per.group)[match(
-                levels(factor(as.character(df$group))), levels(df$group))],
+            p = p + scale_colour_manual(values = unique(col.per.group),
                 name = legend.title) +
                 labs(shape = "Study")#levels(object$study)[study.ind])
             
@@ -460,7 +467,8 @@ internal_graphicModule <-
                                                            levels(df$group)[i]),
                                          aes(x = x0, y = y0, xend = x, yend = y),
                                          #label = "Block"),
-                                         color = unique(col.per.group)[i],size = point.lwd)
+                                         color = unique(col.per.group)[i],
+                                         linewidth = point.lwd)
                 }
             }
             
@@ -543,7 +551,7 @@ internal_graphicModule <-
                                         pch = c(NA, rep(16, length(col.per.group)), NA, NA,
                                                 values.pch),
                                         text = list(outcome = c(legend.title, levels(df$group),
-                                                                "", legend.title.pch, levels(df$pch.levels)))
+                                                                "", legend.title.pch, levels(df$pch)))
                                    )
                                    
                                }
@@ -812,9 +820,11 @@ internal_graphicModule <-
                              lwd=point.lwd)#,...)
                     } else {
                         points(x = df[df$col == i & other, "x"],
-                               y = df[df$col == i & other, "y"],
-                               col = df[df$col == i, ]$col, cex = df[df$col == i, ]$cex,
-                               pch = df[df$col == i, ]$pch,lwd=point.lwd)#,...)
+                        y = df[df$col == i & other, "y"],
+                        col = df[df$col == i, ]$col, 
+                        cex = df[df$col == i, ]$cex,
+                        pch = as.numeric(df[df$col == i, ]$pch.levels),
+                        lwd=point.lwd)#,...)
                     }
                 }
                 
@@ -841,7 +851,7 @@ internal_graphicModule <-
                            col =  c(NA, col.per.group, NA, NA, rep("black",
                                                                    nlevels(df$pch.levels))),
                            legend = c(legend.title, levels(df$group), "",
-                                      legend.title.pch, levels(df$pch.levels)),
+                                      legend.title.pch, levels(df$pch)),
                            pch = c(NA, rep(16, length(col.per.group)), NA, NA, values.pch),
                            cex = max(c(size.legend.title, size.legend)),
                            lty = 0,
