@@ -8,30 +8,31 @@ plotIndiv.sgcca <-
   function(object,
            comp = NULL,
            blocks = NULL,
+           style = "ggplot2",
            ind.names = TRUE,
            group,
-           col.per.group,
-           style = "ggplot2",
+           col,
            ellipse = FALSE,
            ellipse.level = 0.95,
            centroid = FALSE,
            star = FALSE,
+           pch,
            title = NULL,
            subtitle,
            legend = FALSE,
+           legend.title = "Legend",
+           legend.title.pch = "Legend",
+           legend.position = "right",
            X.label = NULL,
            Y.label = NULL,
            Z.label = NULL,
            abline = FALSE,
            xlim = NULL,
            ylim = NULL,
-           col,
-           cex,
-           pch,
-           pch.levels,
-           alpha = 0.2,
            axes.box = "box",
-           layout = NULL,
+           cex,
+           alpha = 0.2,
+           point.lwd = 1,
            size.title = rel(2),
            size.subtitle = rel(1.5),
            size.xlabel = rel(1),
@@ -39,14 +40,31 @@ plotIndiv.sgcca <-
            size.axis = rel(0.8),
            size.legend = rel(1),
            size.legend.title = rel(1.1),
-           legend.title = "Legend",
-           legend.title.pch = "Legend",
-           legend.position = "right",
-           point.lwd = 1,
            ...
            
   )
   {
+
+    # check for inappropriate args
+    extra_args <- list(...)
+    if ("rep.space" %in% names(extra_args)) {
+        warning("'rep.space' is not used for multiblock models, use 'blocks' to specify which data blocks to plot")
+    }
+    if ("study" %in% names(extra_args) || "layout" %in% names(extra_args)) {
+        warning("'study' and 'layout' arguments are only used for MINT models")
+    }
+    # check for deprecated args
+    if ("col.per.group" %in% names(extra_args)) {
+        warning("'col.per.group' is deprecated, please use 'col' to specify colours for each group")
+    }      
+    if ("pch.levels" %in% names(extra_args)) {
+         warning("'pch.levels' is deprecated, please use 'pch' to specify point types")
+    }
+    if ("cols" %in% names(extra_args)) {
+         warning("'cols' is not a valid argument, did you mean 'col' ?")
+    }
+    
+
     plot_parameters = list(
       size.title = size.title,
       size.subtitle = size.subtitle,
@@ -67,7 +85,7 @@ plotIndiv.sgcca <-
     
     #-- rep.space
     rep.space = "multi" # rep.space is not used afterwards, put to "multi" to plot all blocks
-    
+    layout = NULL
     input_average_blocks <- NULL
     valid_average_blocks <- c('average', 'weighted.average')
     
@@ -186,7 +204,6 @@ plotIndiv.sgcca <-
       col = col,
       cex = cex,
       pch = pch,
-      pch.levels = pch.levels,
       display.names = display.names,
       plot_parameters = plot_parameters
     )
